# CombinedRules

Describes a set of rules collected together by combining them based on a properties such as the role which contains them, or the scope at which the rule is matched. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**status** | [**CombinedRulesStatus**](CombinedRulesStatus.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


